@@ -20,12 +20,16 @@ from urllib import parse as urlparse
 import requests
 
 from sushy import exceptions
-from sushy.resources.task_monitor import TaskMonitor
+from sushy.taskmonitor import TaskMonitor
 from sushy import utils
 
 LOG = logging.getLogger(__name__)
 
 
+_SERVER_SIDE_RETRIES = 5
+_SERVER_SIDE_RETRY_DELAY = 3
+
+
 class Connector(object):
 
     def __init__(
@@ -68,7 +72,8 @@ class Connector(object):
         self._session.close()
 
     def _op(self, method, path='', data=None, headers=None, blocking=False,
-            timeout=60, **extra_session_req_kwargs):
+            timeout=60, server_side_retries=_SERVER_SIDE_RETRIES,
+            **extra_session_req_kwargs):
         """Generic RESTful request handler.
 
         :param method: The HTTP method to be used, e.g: GET, POST,
@@ -88,7 +93,10 @@ class Connector(object):
         url = path if urlparse.urlparse(path).netloc else urlparse.urljoin(
             self._url, path)
         headers = headers or {}
-        if not any(k.lower() == 'odata-version' for k in headers):
+        lc_headers = [k.lower() for k in headers]
+        if data is not None and 'content-type' not in lc_headers:
+            headers['Content-Type'] = 'application/json'
+        if 'odata-version' not in lc_headers:
             headers['OData-Version'] = '4.0'
         # TODO(lucasagomes): We should mask the data to remove sensitive
         # information
@@ -137,31 +145,36 @@ class Connector(object):
                               "%s", retry_exc.message)
                     raise
             else:
-                LOG.error("Authentication error detected. Cannot proceed: "
-                          "%s", e.message)
+                if method == 'GET' and url.endswith('SessionService'):
+                    LOG.debug('HTTP GET of SessionService failed %s, '
+                              'this is expected prior to authentication',
+                              e.message)
+                else:
+                    LOG.error("Authentication error detected. Cannot proceed: "
+                              "%s", e.message)
                 raise
+        except exceptions.ServerSideError as e:
+            if method.lower() != 'get' or server_side_retries <= 0:
+                raise
+            else:
+                LOG.warning('Got server side error %s in response to a '
+                            'GET request, retrying after %d seconds',
+                            e, _SERVER_SIDE_RETRY_DELAY)
+                time.sleep(_SERVER_SIDE_RETRY_DELAY)
+                return self._op(method, path, data=data, headers=headers,
+                                blocking=blocking, timeout=timeout,
+                                server_side_retries=server_side_retries - 1,
+                                **extra_session_req_kwargs)
 
         if blocking and response.status_code == 202:
-            if not response.headers.get('location'):
+            if not response.headers.get('Location'):
                 m = ('HTTP response for %(method)s request to %(url)s '
                      'returned status 202, but no Location header'
                      % {'method': method, 'url': url})
                 raise exceptions.ConnectionError(url=url, error=m)
-            timeout_at = time.time() + timeout
-            mon = (TaskMonitor(self, response.headers.get('location'))
-                   .set_retry_after(response.headers.get('retry-after')))
-            while mon.in_progress:
-                LOG.debug('Blocking for in-progress %(method)s call to '
-                          '%(url)s; sleeping for %(sleep)s seconds',
-                          {'method': method, 'url': url,
-                           'sleep': mon.sleep_for})
-                time.sleep(mon.sleep_for)
-                if time.time() >= timeout_at and mon.in_progress:
-                    m = ('Timeout waiting for blocking %(method)s '
-                         'request to %(url)s (timeout = %(timeout)s)'
-                         % {'method': method, 'url': url,
-                            'timeout': timeout})
-                    raise exceptions.ConnectionError(url=url, error=m)
+
+            mon = TaskMonitor.from_response(self, response, path)
+            mon.wait(timeout)
             response = mon.response
             exceptions.raise_for_response(method, url, response)
 
